pub struct PostgresAdapter { /* private fields */ }Expand description
PostgreSQL database adapter.
The default connection pool is created with
PgPoolOptions::connect_lazy_with, which defers all network I/O
until the first query. Non-default database pools are created on
demand via the moka Cache.
Implementations
Sourceimpl PostgresAdapter
impl PostgresAdapter
Sourcepub fn new(config: &DatabaseConfig) -> Self
pub fn new(config: &DatabaseConfig) -> Self
Creates a new PostgreSQL adapter with a lazy connection pool.
Does not establish a database connection. The default pool connects on-demand when the first query is executed.
Sourceimpl PostgresAdapter
impl PostgresAdapter
Sourcepub fn build_tool_router(&self) -> ToolRouter<Self>
pub fn build_tool_router(&self) -> ToolRouter<Self>
Builds the tool router, excluding write tools in read-only mode.
Sourceimpl PostgresAdapter
impl PostgresAdapter
Sourcepub fn tool_list_databases_tool_attr() -> Tool
pub fn tool_list_databases_tool_attr() -> Tool
Generated tool metadata function for list_databases
Sourcepub fn tool_list_databases(
&self,
) -> Pin<Box<dyn Future<Output = Result<Json<ListDatabasesResponse>, ErrorData>> + Send + '_>>
pub fn tool_list_databases( &self, ) -> Pin<Box<dyn Future<Output = Result<Json<ListDatabasesResponse>, ErrorData>> + Send + '_>>
List all accessible databases on the connected database server. Call this first to discover available database names.
Sourcepub fn tool_create_database_tool_attr() -> Tool
pub fn tool_create_database_tool_attr() -> Tool
Generated tool metadata function for create_database
Sourcepub fn tool_create_database(
&self,
Parameters: Parameters<CreateDatabaseRequest>,
) -> Pin<Box<dyn Future<Output = Result<Json<MessageResponse>, ErrorData>> + Send + '_>>
pub fn tool_create_database( &self, Parameters: Parameters<CreateDatabaseRequest>, ) -> Pin<Box<dyn Future<Output = Result<Json<MessageResponse>, ErrorData>> + Send + '_>>
Create a new database.
Sourcepub fn tool_drop_database_tool_attr() -> Tool
pub fn tool_drop_database_tool_attr() -> Tool
Generated tool metadata function for drop_database
Sourcepub fn tool_drop_database(
&self,
Parameters: Parameters<DropDatabaseRequest>,
) -> Pin<Box<dyn Future<Output = Result<Json<MessageResponse>, ErrorData>> + Send + '_>>
pub fn tool_drop_database( &self, Parameters: Parameters<DropDatabaseRequest>, ) -> Pin<Box<dyn Future<Output = Result<Json<MessageResponse>, ErrorData>> + Send + '_>>
Drop an existing database. Cannot drop the currently connected database.
Sourcepub fn tool_list_tables_tool_attr() -> Tool
pub fn tool_list_tables_tool_attr() -> Tool
Generated tool metadata function for list_tables
Sourcepub fn tool_list_tables(
&self,
Parameters: Parameters<ListTablesRequest>,
) -> Pin<Box<dyn Future<Output = Result<Json<ListTablesResponse>, ErrorData>> + Send + '_>>
pub fn tool_list_tables( &self, Parameters: Parameters<ListTablesRequest>, ) -> Pin<Box<dyn Future<Output = Result<Json<ListTablesResponse>, ErrorData>> + Send + '_>>
List all tables in a specific database.
Requires database_name from list_databases.
Sourcepub fn tool_get_table_schema_tool_attr() -> Tool
pub fn tool_get_table_schema_tool_attr() -> Tool
Generated tool metadata function for get_table_schema
Sourcepub fn tool_get_table_schema(
&self,
Parameters: Parameters<GetTableSchemaRequest>,
) -> Pin<Box<dyn Future<Output = Result<Json<TableSchemaResponse>, ErrorData>> + Send + '_>>
pub fn tool_get_table_schema( &self, Parameters: Parameters<GetTableSchemaRequest>, ) -> Pin<Box<dyn Future<Output = Result<Json<TableSchemaResponse>, ErrorData>> + Send + '_>>
Get column definitions (type, nullable, key, default) and foreign key
relationships for a table. Requires database_name and table_name.
Sourcepub fn tool_drop_table_tool_attr() -> Tool
pub fn tool_drop_table_tool_attr() -> Tool
Generated tool metadata function for drop_table
Sourcepub fn tool_drop_table(
&self,
Parameters: Parameters<DropTableRequest>,
) -> Pin<Box<dyn Future<Output = Result<Json<MessageResponse>, ErrorData>> + Send + '_>>
pub fn tool_drop_table( &self, Parameters: Parameters<DropTableRequest>, ) -> Pin<Box<dyn Future<Output = Result<Json<MessageResponse>, ErrorData>> + Send + '_>>
Drop a table from a database. Checks for foreign key dependencies
via the database engine — use cascade to force on PostgreSQL.
Sourcepub fn tool_read_query_tool_attr() -> Tool
pub fn tool_read_query_tool_attr() -> Tool
Generated tool metadata function for read_query
Sourcepub fn tool_read_query(
&self,
Parameters: Parameters<QueryRequest>,
) -> Pin<Box<dyn Future<Output = Result<Json<QueryResponse>, ErrorData>> + Send + '_>>
pub fn tool_read_query( &self, Parameters: Parameters<QueryRequest>, ) -> Pin<Box<dyn Future<Output = Result<Json<QueryResponse>, ErrorData>> + Send + '_>>
Execute a read-only SQL query (SELECT, SHOW, DESCRIBE, USE, EXPLAIN).
Sourcepub fn tool_write_query_tool_attr() -> Tool
pub fn tool_write_query_tool_attr() -> Tool
Generated tool metadata function for write_query
Sourcepub fn tool_write_query(
&self,
Parameters: Parameters<QueryRequest>,
) -> Pin<Box<dyn Future<Output = Result<Json<QueryResponse>, ErrorData>> + Send + '_>>
pub fn tool_write_query( &self, Parameters: Parameters<QueryRequest>, ) -> Pin<Box<dyn Future<Output = Result<Json<QueryResponse>, ErrorData>> + Send + '_>>
Execute a write SQL query (INSERT, UPDATE, DELETE, CREATE, ALTER, DROP).
Sourcepub fn tool_explain_query_tool_attr() -> Tool
pub fn tool_explain_query_tool_attr() -> Tool
Generated tool metadata function for explain_query
Sourcepub fn tool_explain_query(
&self,
Parameters: Parameters<ExplainQueryRequest>,
) -> Pin<Box<dyn Future<Output = Result<Json<QueryResponse>, ErrorData>> + Send + '_>>
pub fn tool_explain_query( &self, Parameters: Parameters<ExplainQueryRequest>, ) -> Pin<Box<dyn Future<Output = Result<Json<QueryResponse>, ErrorData>> + Send + '_>>
Return the execution plan for a SQL query.